<?php

namespace PAR\Service;

use PAR\Factory\TrocaDeInscricaoParceiroFactory;
use Teknisa\Libs\Util\Environment;
use PAR\Util\Procedure\FctAtualizaCnpjCont;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use PAR\Service\FileServerService;

class trocaDeInscricaoParceiroService {

    protected $connection;
    protected $trocaDeInscricaoParceiroFactory;
    protected $environment;
    protected $newCode;
    protected $FileServerService;

     public function __construct(TrocaDeInscricaoParceiroFactory $trocaDeInscricaoParceiroFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager, FileServerService $FileServerService) {
        $this->trocaDeInscricaoParceiroFactory = $trocaDeInscricaoParceiroFactory;
        $this->connection                   = $entityManager->getConnection();
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
        $this->FileServerService            = $FileServerService;
    }

    public function getInscricaoParceiro() {
      $param = array("P_CDOPERADOR" => $this->environment->getCdOperador());
      return $this->trocaDeInscricaoParceiroFactory->getInscricaoParceiro($param);
    }

    public function validarAlteracaoInscricao( $nrnewinscricao, $nrorg){
      try {
        $params = array("NRINSJUREMPR" => $nrnewinscricao);
        $valida = $this->trocaDeInscricaoParceiroFactory->validaOrganizacao($params);
        if($valida>0){
          $retorno = "TEM_ORG";
        } else {
          $params = array("NRINSCRICAOPARC" => $nrnewinscricao,
                            "NRORG" => $nrorg);
          $valida = $this->trocaDeInscricaoParceiroFactory->validaParceiro($params);
          if($valida>0){
            $retorno = "TEM_PARC";
          } else {
            $retorno = "OK";
          }
        }
        return $retorno;
      } catch(\Exception $e){
          $this->connection->rollback();
          throw $e;
      }
    }

    public function alterarInscricaoParceiro($nrparcnegocio, $nrnewinscricao, $nroldinscricao, $nmprincipalparc, $nmsecundarioparc, $dsjustificativa, $idinativaparc, $dscaminhoarq, $nrorg, $operador) {
        $this->connection->beginTransaction();
        try {
            $this->executarProcedureAltCnpj($nrnewinscricao, $nroldinscricao, $nmprincipalparc, $nmsecundarioparc, $dsjustificativa, $idinativaparc, $nrorg, $operador);
            $this->inserirLogAltCnpjParceiro($nrparcnegocio, $nrnewinscricao, $nroldinscricao, $dscaminhoarq, $dsjustificativa, $nrorg, $operador);
            $this->connection->commit();
        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function executarProcedureAltCnpj($nrnewinscricao, $nroldinscricao, $nmprincipalparc, $nmsecundarioparc, $dsjustificativa, $idinativaparc, $nrorg, $operador){
        $procedure = new FctAtualizaCnpjCont($this->connection);
        $procedure->executar($nrnewinscricao, $nroldinscricao, $nmprincipalparc, $nmsecundarioparc, $dsjustificativa, $idinativaparc, $nrorg, $operador);
    }

    public function inserirLogAltCnpjParceiro($nrparceiro, $nrnewinscricao, $nroldinscricao, $dscaminhoarq, $dsjustificativa, $nrorg, $operador) {
        $nraltcnpjparceiro = $this->newCode->getCodeByTableName("FCT_LOGALTCNPJPARCEIRO", $nrorg, 1, 10, true);

        $file = null;
        if (is_array($dscaminhoarq) && count($dscaminhoarq) > 0) {
            $file = $this->FileServerService->uploadFiles($dscaminhoarq, 'anexo_termo_anuencia_contrato');
        }
        $params = array(
            "NRALTCNPJPARCEIRO" => $nraltcnpjparceiro,
            "NROLDINSCRICAO"    => $nroldinscricao,
            "NRNEWINSCRICAO"    => $nrnewinscricao,
            "DSJUSTIFICATIVA"   => $dsjustificativa,
            "NMARQUIVO"         => $file[0] ? $file[0]["name"] : null,
            "DSTIPO"            => $file[0] ? $file[0]["type"] : null,
            "VRTAMANHO"         => $file[0] ? $file[0]["size"] : null,
            "DSCAMINHOARQ"      => $file[0] ? $file[0]["path"] : null,
            "NRORG"             => $nrorg,
            "CDOPERINCLUSAO"    => $operador
        );
        $this->trocaDeInscricaoParceiroFactory->inserirLogAltCnpjParceiro($params);

        if ($file) {
           // $this->anexarDocumentoContrato($nrnewinscricao, $file, $nrorg, $operador);
        }
    }

    public function getPermissaoAlteracaoInscParceiro($nrparcnegocio, $nrorg) {
        try{
            $params = array(
                "NRPARCNEGOCIO" => $nrparcnegocio,
                "NRORG"         => $nrorg
            );

            $contratosDelphi = $this->trocaDeInscricaoParceiroFactory->getContratosApenasDelphi($params);
            return count($contratosDelphi) > 0 ? false : true;
        } catch(\Exception $e) {
          throw $e;
        }
    }

    public function getTermoAnuenciaParceiro($nrinscricao, $nrorg) {
      try { 
          $result = array();
          $params = array(
              "NRINSCRICAOPARC" => $nrinscricao,
              "NRORG" => $nrorg
          );
          
          $documentos = $this->trocaDeInscricaoParceiroFactory->getTermoAnuenciaParceiro($params); 
          if(count($documentos) <= 0) {
              throw new \Exception("Operação bloqueada!<br>Não há termos de anuência ligados a este parceiro de negócio.");
          } else {
              foreach($documentos as $documento) {
                $microtime = microtime(true);
                $microtime = str_replace(".", "_", $microtime);

                $fileName  = $microtime . "_" . str_replace(",", "_", $documento["NMARQUIVO"]);
                
                $fileDirTemp = $this->FileServerService->downloadDocFileServer($documento["DSCAMINHOARQ"], $fileName, $nrorg);
                $result[] = $fileDirTemp;
                //$fileName    = base64_encode($fileName);
                //$result[]    = "/downloadArquivo?requestType=Row&row[FILENAME]=" . $fileName . "&row[FILETYPE]=" . $documento["DSTIPO"];
            }
        }
        return $result;
      } catch(\Exception $e) {
          throw $e;
      }
  }

}