/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/* Nome: 0005_DENSTPO_USR_EXPORTAAF_DENADAI.sql                               */
/*                                                                            */
/* Descrio:                                                                 */
/* Procedure destinada a possibilitar que as autorizaes de fornecimento     */
/* (AF's) geradas pelo sistema da Teknisa sejam importadas no sistema da      */
/* Microsiga e, para isso, a procedure alimentar duas tabelas intermedirias */
/* entre os dois sistemas                                                     */
/* (tabelas pertencentes ao banco de dados do sistema da Microsiga).          */
/* Criao:                                                                   */
/* 29/07/2008 - Raquel Cunha                                                  */
/******************************************************************************/

CREATE OR REPLACE
PROCEDURE USR_EXPORTAAF_DENADAI IS
   V_FILIAL VARCHAR(10);
   V_CONTFORN VARCHAR(30);
   V_FORMPGTO VARCHAR(3);
   V_FILENT VARCHAR(10);
   V_VRFRETE FLOAT;
   V_DESPESA FLOAT;
   V_SEGURO FLOAT;
   V_DESC1 FLOAT;
   V_DESC2 FLOAT;
   V_PRODINTE VARCHAR(20);
   V_VRALIQITMAF FLOAT;
   V_QTSOLIPROD FLOAT;
   V_NUM4 VARCHAR(10);
   V_NUM5 VARCHAR(10);
   V_NRSEQ VARCHAR(4);
   V_IDTPFRETFORN VARCHAR(1);
   V_NMPRODUTO VARCHAR(30);
BEGIN
   V_NRSEQ := '0001';
   FOR C_AFEXPORT IN
      (SELECT CDFILDEST, CDFILLANC, NRAUTOFORN,
              DTAUTOFORN, CDFORNECED, VRTOTALAF
       FROM AUTOFORNE
       WHERE NVL(USR_IDEXPORTA, 'S') = 'S'
         AND USR_DTEXPORTA IS NULL
       ORDER BY CDFILDEST, CDFILLANC, NRAUTOFORN
       )
   LOOP
      FOR C_ITEMAUTF IN
         (SELECT CDPRODUTO, CDMARCA, DTPROGENTAF,
                 QTPROGENTAF, VRPREUNIAF, DTENTRITMSOL,
                 TXOBSITMAF
          FROM ITEMAUTF
          WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
            AND CDFILLANC = C_AFEXPORT.CDFILLANC
            AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
          ORDER BY CDFILDEST, CDFILLANC, NRAUTOFORN, CDMARCA, CDPRODUTO, DTPROGENTAF
         )
      LOOP
         SELECT MAX(CDGRUPFILI)
         INTO V_FILIAL
         FROM FILGRUPFILI
         WHERE CDFILIAL = C_AFEXPORT.CDFILLANC
           AND USR_IDPROTHEUS = 'S';

         SELECT MAX(CDFORMPGTO),
                MAX(IDTPFRETFORN)
         INTO V_FORMPGTO,
              V_IDTPFRETFORN
         FROM FORNECEDOR
         WHERE CDFORNECED = C_AFEXPORT.CDFORNECED;

         SELECT MAX(NMCONTFORN)
         INTO V_CONTFORN
         FROM ENDEFORN
         WHERE CDFORNECED = C_AFEXPORT.CDFORNECED
           AND IDTPENDEFORN = 'P';

         SELECT MAX(CDGRUPFILI)
         INTO V_FILENT
         FROM FILGRUPFILI
         WHERE CDFILIAL = C_AFEXPORT.CDFILDEST
           AND USR_IDPROTHEUS = 'S';

         SELECT MAX(VRENCARGOAF)
         INTO V_VRFRETE
         FROM ENCARGOAF
         WHERE CDENCARGO = '01'
           AND CDFILDEST = C_AFEXPORT.CDFILDEST
           AND CDFILLANC = C_AFEXPORT.CDFILLANC
           AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
           AND DTENTRENCAF = C_ITEMAUTF.DTPROGENTAF;

         SELECT MAX(VRENCARGOAF)
         INTO V_DESPESA
         FROM ENCARGOAF
         WHERE CDENCARGO = '04'
           AND CDFILDEST = C_AFEXPORT.CDFILDEST
           AND CDFILLANC = C_AFEXPORT.CDFILLANC
           AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
           AND DTENTRENCAF = C_ITEMAUTF.DTPROGENTAF;

         SELECT MAX(VRENCARGOAF)
         INTO V_SEGURO
         FROM ENCARGOAF
         WHERE CDENCARGO = '02'
           AND CDFILDEST = C_AFEXPORT.CDFILDEST
           AND CDFILLANC = C_AFEXPORT.CDFILLANC
           AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
           AND DTENTRENCAF = C_ITEMAUTF.DTPROGENTAF;

         SELECT SUM(VRDESCITMAF)
         INTO V_DESC1
         FROM ITEMAUTF
         WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
           AND CDFILLANC = C_AFEXPORT.CDFILLANC
           AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN;

         SELECT MAX(VRENCARGOAF)
         INTO V_DESC2
         FROM ENCARGOAF
         WHERE CDENCARGO = '03'
           AND CDFILDEST = C_AFEXPORT.CDFILDEST
           AND CDFILLANC = C_AFEXPORT.CDFILLANC
           AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
           AND DTENTRENCAF = C_ITEMAUTF.DTPROGENTAF;

         SELECT MAX(W4_NUM)
         INTO V_NUM4
         FROM USR_ZW4
         WHERE W4_FILIAL = SUBSTR(V_FILIAL, 9, 2)
           AND W4_NUM = SUBSTR(C_AFEXPORT.NRAUTOFORN, 5, 6)
           AND W4_FILENT = SUBSTR(V_FILENT, 9, 2);

         IF V_NUM4 IS NULL THEN
            INSERT INTO USR_ZW4
                (W4_EMPRESA, W4_FILIAL, W4_NUM,
                 W4_EMISSAO, W4_CGC, W4_CONTATO, W4_MOEDA, W4_COND,
                 W4_FILENT, W4_FRETE, W4_DESPESA, W4_SEGURO,
                 W4_DESC1, W4_DESC2, W4_DESC3, W4_VLDESC,
                 W4_TPFRETE, W4_VLTODN, W4_TPEDI, W4_DTGRV,
                 W4_HRGRV, W4_DTIMP, W4_HRIMP)
            VALUES
                (SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2), SUBSTR(C_AFEXPORT.NRAUTOFORN, 5, 6),
                 TO_CHAR(C_AFEXPORT.DTAUTOFORN, 'DDMMYYYY'), SUBSTR(C_AFEXPORT.CDFORNECED, 1, 14),
                 SUBSTR(V_CONTFORN, 1, 15), '1', V_FORMPGTO, SUBSTR(V_FILENT, 9, 2),
                 V_VRFRETE, V_DESPESA, V_SEGURO, V_DESC1, V_DESC2, NULL, NULL,
                 V_IDTPFRETFORN, C_AFEXPORT.VRTOTALAF, '1', TO_CHAR(TRUNC(SYSDATE), 'DDMMYYYY'),
                 TO_CHAR(SYSDATE, 'HH24MI'), NULL, '');
         END IF;

         SELECT MAX(CDPRODINTE),
                MAX(NMPRODUTO)
         INTO V_PRODINTE,
              V_NMPRODUTO
         FROM PRODUTO
         WHERE CDPRODUTO = C_ITEMAUTF.CDPRODUTO;

         SELECT MAX(QTSOLIPROD)
         INTO V_QTSOLIPROD
         FROM ITEMSOLI
         WHERE CDFILSOLI = C_AFEXPORT.CDFILDEST
           AND CDFILLAN = C_AFEXPORT.CDFILLANC
           AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
           AND DTPROGENTR = C_ITEMAUTF.DTENTRITMSOL;

         SELECT MAX(VRALIQITMAF)
         INTO V_VRALIQITMAF
         FROM IMPITMAF
         WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
           AND CDFILLANC = C_AFEXPORT.CDFILLANC
           AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN
           AND CDPRODUTO = C_ITEMAUTF.CDPRODUTO
           AND CDMARCA = C_ITEMAUTF.CDMARCA
           AND DTPROGENTAF = C_ITEMAUTF.DTPROGENTAF
           AND CDIMPOSTO = '10';

         SELECT MAX(W5_NUM)
         INTO V_NUM5
         FROM USR_ZW5
         WHERE W5_FILIAL = SUBSTR(V_FILIAL, 9, 2)
           AND W5_NUM = SUBSTR(C_AFEXPORT.NRAUTOFORN, 5, 6)
           AND W5_ITEM = V_NRSEQ;

         IF V_NUM5 IS NULL THEN
            INSERT INTO USR_ZW5
                (W5_EMPRESA, W5_FILIAL, W5_NUM,
                 W5_CGC, W5_ITEM, W5_PRODUTO, W5_DESCRI,
                 W5_QUANT, W5_QTDSOL, W5_PRECO, W5_TOTAL,
                 W5_IPI, W5_DATPRF, W5_LOCAL, W5_LOCENT,
                 W5_OBS, W5_CC, W5_TPEDI, W5_DTGRV, W5_HRGRV,
                 W5_DTIMP, W5_HRIMP)
            VALUES
               (SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2),
                SUBSTR(C_AFEXPORT.NRAUTOFORN, 5, 6),
                SUBSTR(C_AFEXPORT.CDFORNECED, 1, 14), V_NRSEQ,
                SUBSTR(V_PRODINTE, 1, 15), V_NMPRODUTO, C_ITEMAUTF.QTPROGENTAF,
                V_QTSOLIPROD, C_ITEMAUTF.VRPREUNIAF,
                (C_ITEMAUTF.QTPROGENTAF*C_ITEMAUTF.VRPREUNIAF),
                V_VRALIQITMAF, TO_CHAR(TRUNC(C_ITEMAUTF.DTPROGENTAF), 'DDMMYYYY'),
                '', '', NVL(SUBSTR(C_ITEMAUTF.TXOBSITMAF, 1, 30), ''),
                C_AFEXPORT.CDFILDEST, '1', TO_CHAR(TRUNC(SYSDATE), 'DDMMYYYY'),
                TO_CHAR(SYSDATE, 'HH24MI'), NULL, '');

            V_NRSEQ := LPAD(RTRIM(TO_CHAR(TO_NUMBER(RTRIM(V_NRSEQ))+ 1)),4,'0');
         END IF;
      END LOOP;

      UPDATE AUTOFORNE
      SET USR_IDEXPORTA = 'N',
          USR_DTEXPORTA = SYSDATE
      WHERE CDFILDEST = C_AFEXPORT.CDFILDEST
        AND CDFILLANC = C_AFEXPORT.CDFILLANC
        AND NRAUTOFORN = C_AFEXPORT.NRAUTOFORN;

      V_NRSEQ := '0001';
   END LOOP;
END;

-- VERSAO --
BEGIN ATUVEROBJ('USR_EXPORTAAF_DENADAI','5.03.014'); END;
/

