import {
    Http, IDictionary, Metadata,
} from '@zeedhi/core';
import {
    AlertService, DialogService, Form, LoadingService, Modal, ModalService, TextInput, Button, Text,
} from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';
import { ZdButton } from '@zeedhi/vuetify';

export class TrocaDeInscricaoParceiroController {
    public gridVisivel : boolean = true;

    public currentRow : any = {};

    public NAMEOFCORPORATE: string = '';

    private modalAlterarInscricao!: Modal;

    get formVisivel() {
        return !this.gridVisivel;
    }

    public async createBasicUsageModal() {
        this.modalAlterarInscricao = await ModalService.createFromJson('sources/trocaDeInscricaoParceiroModal', true);
    }

    public destroyBasicUsageModal() {
        this.modalAlterarInscricao?.destroy();
    }

    public async alterarInscricaoParceiro() {
        if (!Metadata.getInstance<Form>('formModalTrocaInscricaoParceiro').validate()) {
            this.alertMessage('Existem campos obrigatórios não preenchidos.', 'error');
        } else {
            const formulario = Metadata.getInstance<Form>('formModalTrocaInscricaoParceiro').childrenInstances;
            const novaInscricao = formulario[1].value.replace(/[./-]/g, '');
            const oldInscricao = this.currentRow.NRINSCRICAOPARC.replace(/[./-]/g, '');
            if (oldInscricao === novaInscricao) {
                this.alertMessage('Não houve alteração no número de inscrição do parceiro.', 'error');
            } else {
                const file = await Utilities.buildArrayToUpload('fileMultipleResult');
                const params = {
                    NRPARCNEGOCIO: this.currentRow.NRPARCNEGOCIO,
                    NRNEWINSCRICAO: novaInscricao,
                    NROLDINSCRICAO: this.currentRow.NRINSCRICAOPARC,
                    NMPRINCIPALPARC: formulario[4].value,
                    NMSECUNDARIPARC: formulario[5].value,
                    DSJUSTIFICATIVA: formulario[8].value,
                    IDINATIVAPARC: formulario[6].value,
                    DSCAMINHOARQ: file,
                };
                LoadingService.show();
                Http.post('/validarInscricaoParceiro', params).then((response: IDictionary) => {
                    const valida = response.data.dataset.alterainscricao.VALIDA;
                    if (valida === 'OK') {
                        Http.post('/alterarInscricaoParceiro', params).then(() => {
                            this.alertMessage('Processo realizado com sucesso!', 'success');
                            LoadingService.hide();
                            this.closeModalAlterarInscricao();
                            this.voltarGrid();
                            this.atualizaGrid();
                        }).catch((error: any) => {
                            LoadingService.hide();
                            Utilities.showErrorMessage(error);
                        });
                    } else if (valida === 'TEM_PARC') {
                        LoadingService.hide();
                        DialogService.show({
                            name: 'buttons-dialog',
                            type: 'warning',
                            title: 'Cancel Operation',
                            text: 'Já existe um Parceiro de Negócio ativo com a inscrição informada. Esse Parceiro será considerado.<br><br>Deseja continuar?',
                            buttons: [
                                {
                                    name: 'Sim',
                                    component: 'ZdButton',
                                    label: 'YES',
                                    events: this.yes,
                                    outline: true,
                                },
                                {
                                    name: 'Não',
                                    component: 'ZdButton',
                                    label: 'NO',
                                    events: this.no,
                                },
                            ],
                        });
                    } else {
                        LoadingService.hide();
                        this.alertMessage('Já existe uma organização ativa para a inscrição informada.', 'error');
                    }
                }).catch((error: any) => {
                    LoadingService.hide();
                    Utilities.showErrorMessage(error);
                });
            }
        }
    }

    public async sobreporInscicaoParceiro() {
        const formulario = Metadata.getInstance<Form>('formModalTrocaInscricaoParceiro').childrenInstances;
        const novaInscricao = formulario[1].value.replace(/[./-]/g, '');
        const file = await Utilities.buildArrayToUpload('fileMultipleResult');
        const params = {
            NRPARCNEGOCIO: this.currentRow.NRPARCNEGOCIO,
            NRNEWINSCRICAO: novaInscricao,
            NROLDINSCRICAO: this.currentRow.NRINSCRICAOPARC,
            NMPRINCIPALPARC: formulario[4].value,
            NMSECUNDARIPARC: formulario[5].value,
            DSJUSTIFICATIVA: formulario[8].value,
            IDINATIVAPARC: formulario[6].value,
            DSCAMINHOARQ: file,
        };
        LoadingService.show();
        Http.post('/alterarInscricaoParceiro', params).then(() => {
            this.alertMessage('Processo realizado com sucesso!', 'success');
            DialogService.hide();
            LoadingService.hide();
            this.closeModalAlterarInscricao();
            this.voltarGrid();
            this.atualizaGrid();
        }).catch((error: any) => {
            LoadingService.hide();
            Utilities.showErrorMessage(error);
        });
    }

    private no: any = {
        click: () => DialogService.hide(),
    };

    public openmodalAlterarInscricao() {
        const params = {
            NRPARCNEGOCIO: this.currentRow.NRPARCNEGOCIO,
        };
        LoadingService.show();
        Http.post('/getPermissaoAlteracaoInscParceiro', params).then((response: IDictionary) => {
            if (response.data.dataset && response.data.dataset.parcnegocio && response.data.dataset.parcnegocio.PERMITEALTSM) {
                this.modalAlterarInscricao.show();
                LoadingService.hide();
            } else {
                this.alertMessage('Não é possível alterar o número de inscrição de parceiros que possuam contratos Delphi sem vínculo com o SM.', 'error');
                LoadingService.hide();
            }
        }).catch((error: any) => {
            LoadingService.hide();
            Utilities.showErrorMessage(error);
        });
    }

    private yes: any = {
        click: () => this.sobreporInscicaoParceiro(),
    };

    public montarModalInscricaoParceiro() {
        Metadata.getInstance<Form>('formModalTrocaInscricaoParceiro').children[0].value = this.currentRow.CDTIPOINSCRICAO;
        Metadata.getInstance<Form>('formModalTrocaInscricaoParceiro').children[2].value = this.currentRow.IDATIVO;
        Metadata.getInstance<Form>('formModalTrocaInscricaoParceiro').children[3].value = this.currentRow.CDTIPOPARCPRINCIPAL;
        Metadata.getInstance<Form>('formModalTrocaInscricaoParceiro').children[4].value = this.currentRow.NMPRINCIPALPARC;
        Metadata.getInstance<Form>('formModalTrocaInscricaoParceiro').children[5].value = this.currentRow.NMSECUNDARIPARC;
        Metadata.getInstance<Form>('formModalTrocaInscricaoParceiro').children[7].value = this.currentRow.NMOPERRESPONSAVEL;
    }

    public closeModalAlterarInscricao() {
        this.modalAlterarInscricao.hide();
    }

    public openPreview({ row }: any) {
        this.gridVisivel = false;
        this.currentRow = row;
        this.montarAbaInscricaoParceiro();
    }

    public voltarGrid() {
        this.gridVisivel = true;
    }

    public montarAbaInscricaoParceiro() {
        Metadata.getInstance<TextInput>('CDTIPOINSCRICAO').value = this.currentRow.CDTIPOINSCRICAO;
        Metadata.getInstance<TextInput>('NRINSCRICAOPARC').value = this.currentRow.NRINSCRICAOPARC;
        Metadata.getInstance<TextInput>('IDATIVO').value = this.currentRow.IDATIVO;
        Metadata.getInstance<TextInput>('CDTIPOPARCPRINCIPAL').value = this.currentRow.CDTIPOPARCPRINCIPAL;
        Metadata.getInstance<TextInput>('NMPRINCIPALPARC').value = this.currentRow.NMPRINCIPALPARC;
        Metadata.getInstance<TextInput>('NMSECUNDARIPARC').value = this.currentRow.NMSECUNDARIPARC;
        Metadata.getInstance<TextInput>('NMOPERRESPONSAVEL').value = this.currentRow.NMOPERRESPONSAVEL;
        Metadata.getInstance<Text>('nomeDaCorporacao').text = this.currentRow.NMPRINCIPALPARC;
        Metadata.getInstance<TextInput>('DTALTCNPJPARCEIRO').value = this.currentRow.DTALTCNPJPARCEIRO;
        Metadata.getInstance<TextInput>('NMOPERALTCNPJPARC').value = this.currentRow.NMOPERALTCNPJPARC;
        Metadata.getInstance<TextInput>('NMARQUIVO').value = this.currentRow.NMARQUIVO;
        Metadata.getInstance<TextInput>('DSJUSTIFICATIVA').value = this.currentRow.DSJUSTIFICATIVA;
        if (this.currentRow.NMARQUIVO !== null) {
            Metadata.getInstance<ZdButton>('BTNDOWNLOAD').disabled = false;
        } else {
            Metadata.getInstance<ZdButton>('BTNDOWNLOAD').disabled = true;
        }
    }

    public openFilter({ component }: any) {
        const filterButton = Metadata.getInstance<Button>(`${component.name}_filterButton`);
        filterButton.click({} as Event, {} as HTMLElement);
    }

    public atualizaGrid() {
        const atualizar = Metadata.getInstance<Button>('gridTrocaInscricaoParceiro_refreshButton');
        atualizar.click({} as Event, {} as HTMLElement);
    }

    public expandir({ component }: any) {
        const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
        form.isVisible = !form.isVisible;
        component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
    }

    public alertMessage(message: string, type: string) {
        AlertService.show({
            name: 'basic-alert',
            text: message,
            top: true,
            left: false,
            timeout: 3000,
            color: type,
        });
    }

    public baixarTermoAnuenciaParceiro() {
        const params = {
            NRINSCRICAOPARC: this.currentRow.NRINSCRICAOPARC,
        };
        LoadingService.show();
        Http.post('/getTermoAnuenciaParceiro', params).then((response: IDictionary) => {
            if (response.data.dataset && response.data.dataset.URLDOCUMENTO && response.data.dataset.URLDOCUMENTO.length > 0) {
                const documentos = response.data.dataset.URLDOCUMENTO;
                // var urlDocumento = window.document.backendIndexUrl + link;
                window.open(documentos[0]);
            }
            LoadingService.hide();
        }).catch((error: any) => {
            LoadingService.hide();
            Utilities.showErrorMessage(error);
        });
    }
}
