import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Metadata, Http } from '@zeedhi/core';
import {
    LoadingService, TextInput, IGridEvent, DialogService,
} from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';

export class PartnerClassificationController {
    public addPartnerClassification() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid');
        // const newId = (grid.datasource.total + 1).toString();
        const newId = 0;

        grid.addNewRow({ NRTPCLASSIFICAPARC: newId }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NMCLASSIFICAPARC_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    public async insertPartnerClassification({ event }: IGridEvent) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid');
        if (Utilities.validateGrid(grid)) {
            const classifications = grid.getEditedRows();
            LoadingService.show();
            try {
                await Http.post('/insertNewPartnerClassification', classifications);
                await grid.cancelEditedRows();
                await grid.reload();
                Utilities.showSuccessMessage();
            } catch (e) {
                Utilities.showErrorMessage(e);
            }
            LoadingService.hide();
        }
    }

    showDialogWithButtonsGrid({ event }: any) {
        event.preventDefault();
        DialogService.show({
            name: 'dialog-deletar-partner-classification',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deletePartnerClassification();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public deletePartnerClassification() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid');
        LoadingService.show();
        Http.post('/deletePartnerClassification', grid.selectedRows).then(() => {
            grid.selectedRows = [];
            grid.cancelEditedRows();
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }
}
