/* eslint-disable */
export class ValidaInscricao {
    
    public static validateCPF(CPF: string) {
        if (CPF === null || CPF === undefined) {
            return false;
        } else {
            CPF = CPF.toString().replace(/[\D]+/g, '');

            if (CPF.length != 11) return false;

            if (CPF == "00000000000" ||
                CPF == "11111111111" ||
                CPF == "22222222222" ||
                CPF == "33333333333" ||
                CPF == "44444444444" ||
                CPF == "55555555555" ||
                CPF == "66666666666" ||
                CPF == "77777777777" ||
                CPF == "88888888888" ||
                CPF == "99999999999") return false;

            let soma = 0;
            let resto: any;

            for (let i = 1; i <= 9; i++) soma = soma + parseInt(CPF.substring(i - 1, i)) * (11 - i);
            resto = (soma * 10) % 11;

            if ((resto == 10) || (resto == 11)) resto = 0;
            if (resto != parseInt(CPF.substring(9, 10))) return false; //'resto' é o 1º dígito de validação do CPF

            soma = 0;
            for (let i = 1; i <= 10; i++) soma = soma + parseInt(CPF.substring(i - 1, i)) * (12 - i);
            resto = (soma * 10) % 11;

            if ((resto == 10) || (resto == 11)) resto = 0;
            if (resto != parseInt(CPF.substring(10, 11))) return false; //'resto' é o 2º dígito de validação do CPF

            return true;
        }
    }

    public static validateCNPJ(CNPJ: string) {
        if (CNPJ === undefined || CNPJ === null) {
            return false;
        } else {
            CNPJ = CNPJ.toString().replace(/[\D]+/g, '');

            if (CNPJ.length != 14) return false;

            if (CNPJ == "00000000000000" ||
                CNPJ == "11111111111111" ||
                CNPJ == "22222222222222" ||
                CNPJ == "33333333333333" ||
                CNPJ == "44444444444444" ||
                CNPJ == "55555555555555" ||
                CNPJ == "66666666666666" ||
                CNPJ == "77777777777777" ||
                CNPJ == "88888888888888" ||
                CNPJ == "99999999999999") return false;

            let tamanho: any = CNPJ.length - 2;
            let numeros: any = CNPJ.substring(0, tamanho);
            let digitos: any = CNPJ.substring(tamanho);
            let soma: any = 0;
            let pos: any = tamanho - 7;

            for (let i = tamanho; i >= 1; i--) {
                soma += numeros.charAt(tamanho - i) * pos--;
                if (pos < 2) pos = 9;
            }

            let resultado = (soma % 11 < 2) ? 0 : 11 - soma % 11;
            if (resultado != digitos.charAt(0)) return false; //'resultado' é o 1º digito de validação do CNPJ

            tamanho = tamanho + 1;
            numeros = CNPJ.substring(0, tamanho);
            soma = 0;
            pos = tamanho - 7;

            for (let i = tamanho; i >= 1; i--) {
                soma += numeros.charAt(tamanho - i) * pos--;
                if (pos < 2) pos = 9;
            }

            resultado = (soma % 11 < 2) ? 0 : 11 - soma % 11;
            if (resultado != digitos.charAt(1)) return false; //'resultado' é o 2º digito de validação do CNPJ

            return true;
        }
    }
}